@@ -3,9 +3,9 @@ test_that("add_prompt adds info as attributes of the element if not an image", {
   x <- shiny::actionButton("test", "test")
   y <- add_prompt(x, message = "foo")
 
-  expect_equal(
-    as.character(y),
-    '<button aria-label="foo" class="btn btn-default action-button hint--bottom" id="test" type="button">test</button>'
+  expect_match(
+    htmltools::tagGetAttribute(y, "class"),
+    'hint--bottom'
   )
 
 })
@@ -34,9 +34,9 @@ test_that("options are in the right form", {
   x <- shiny::actionButton("test", "test")
   y <- add_prompt(x, message = "foo", bounce = TRUE, animate = FALSE)
 
-  expect_equal(
-    as.character(y),
-    '<button aria-label="foo" class="btn btn-default action-button hint--bottom hint--bounce hint--no-animate" id="test" type="button">test</button>'
+  expect_match(
+    htmltools::tagGetAttribute(y, "class"),
+    'hint--bottom hint--bounce hint--no-animate'
   )
 
 })
